---
---
Do not maintain backwards compatibility when refactoring code
When updating a function or class, do not use specifiers such as 
enhanced, simple, optimized in file names or doc strings. Just update the existing code
